==> bacula_5.0.1.orig.tar.gz: bacula-5.0.1/src/qt-console/clients/clients.h <==
#ifndef _CLIENTS_H_
#define _CLIENTS_H_
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2007-2007 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from
   many others, a complete list can be found in the file AUTHORS.
   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version two of the GNU General Public
   License as published by the Free Software Foundation and included
   in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

   Bacula® is a registered trademark of Kern Sibbald.
   The licensor of Bacula is the Free Software Foundation Europe
   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
   Switzerland, email:ftf@fsfeurope.org.
*/
/*
 *   Version $Id$
 *
 *   Dirk Bartley, March 2007
 */

#include <QtGui>
#include "ui_clients.h"
#include "console.h"
#include "pages.h"

class Clients : public Pages, public Ui::ClientForm
{
   Q_OBJECT 

public:
   Clients();
   ~Clients();
   virtual void PgSeltreeWidgetClicked();
   virtual void currentStackItem();

public slots:
   void tableItemChanged(QTableWidgetItem *, QTableWidgetItem *);

private slots:
   void populateTable();
   void showJobs();
   void consoleStatusClient();
   void statusClientWindow();
   void consolePurgeJobs();
   void prune();

private:
   void createContextMenu();
   void settingsOpenStatus(QString& client);
   QString m_currentlyselected;
   bool m_populated;
   bool m_firstpopulation;
   bool m_checkcurwidget;
};

#endif /* _CLIENTS_H_ */

==> bacula_5.0.3.orig.tar.gz: bacula-5.0.3/src/qt-console/clients/clients.h <==
#ifndef _CLIENTS_H_
#define _CLIENTS_H_
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2007-2007 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from
   many others, a complete list can be found in the file AUTHORS.
   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version three of the GNU Affero General Public
   License as published by the Free Software Foundation and included
   in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU Affero General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

   Bacula® is a registered trademark of Kern Sibbald.
   The licensor of Bacula is the Free Software Foundation Europe
   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
   Switzerland, email:ftf@fsfeurope.org.
*/
/*
 *   Version $Id$
 *
 *   Dirk Bartley, March 2007
 */

#include <QtGui>
#include "ui_clients.h"
#include "console.h"
#include "pages.h"

class Clients : public Pages, public Ui::ClientForm
{
   Q_OBJECT 

public:
   Clients();
   ~Clients();
   virtual void PgSeltreeWidgetClicked();
   virtual void currentStackItem();

public slots:
   void tableItemChanged(QTableWidgetItem *, QTableWidgetItem *);

private slots:
   void populateTable();
   void showJobs();
   void consoleStatusClient();
   void statusClientWindow();
   void consolePurgeJobs();
   void prune();

private:
   void createContextMenu();
   void settingsOpenStatus(QString& client);
   QString m_currentlyselected;
   bool m_populated;
   bool m_firstpopulation;
   bool m_checkcurwidget;
};

#endif /* _CLIENTS_H_ */
